==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSQLQuery.java <==
// java wrapper for vtkSQLQuery object
//

package vtk;
import vtk.*;

public class vtkSQLQuery extends vtkRowQuery
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SetQuery_2(String id0);
  public boolean SetQuery(String id0)
    { return SetQuery_2(id0); }

  private native String GetQuery_3();
  public String GetQuery()
    { return GetQuery_3(); }

  private native boolean IsActive_4();
  public boolean IsActive()
    { return IsActive_4(); }

  private native boolean Execute_5();
  public boolean Execute()
    { return Execute_5(); }

  private native boolean BeginTransaction_6();
  public boolean BeginTransaction()
    { return BeginTransaction_6(); }

  private native boolean CommitTransaction_7();
  public boolean CommitTransaction()
    { return CommitTransaction_7(); }

  private native boolean RollbackTransaction_8();
  public boolean RollbackTransaction()
    { return RollbackTransaction_8(); }

  private native long GetDatabase_9();
  public vtkSQLDatabase GetDatabase() {
    long temp = GetDatabase_9();

    if (temp == 0) return null;
    return (vtkSQLDatabase)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean BindParameter_10(int id0,char id1);
  public boolean BindParameter(int id0,char id1)
    { return BindParameter_10(id0,id1); }

  private native boolean BindParameter_11(int id0,double id1);
  public boolean BindParameter(int id0,double id1)
    { return BindParameter_11(id0,id1); }

  private native boolean BindParameter_12(int id0,String id1);
  public boolean BindParameter(int id0,String id1)
    { return BindParameter_12(id0,id1); }

  private native boolean ClearParameterBindings_13();
  public boolean ClearParameterBindings()
    { return ClearParameterBindings_13(); }

  private native String EscapeString_14(String id0,boolean id1);
  public String EscapeString(String id0,boolean id1)
    { return EscapeString_14(id0,id1); }

  public vtkSQLQuery() { super(); }

  public vtkSQLQuery(long id) { super(id); }

}

==> vtk-8.2.0-1-armv7h.pkg.tar.xz: vtk/vtkSQLQuery.java <==
// java wrapper for vtkSQLQuery object
//

package vtk;
import vtk.*;

public class vtkSQLQuery extends vtkRowQuery
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SetQuery_2(String id0);
  public boolean SetQuery(String id0)
    { return SetQuery_2(id0); }

  private native String GetQuery_3();
  public String GetQuery()
    { return GetQuery_3(); }

  private native boolean IsActive_4();
  public boolean IsActive()
    { return IsActive_4(); }

  private native boolean Execute_5();
  public boolean Execute()
    { return Execute_5(); }

  private native boolean BeginTransaction_6();
  public boolean BeginTransaction()
    { return BeginTransaction_6(); }

  private native boolean CommitTransaction_7();
  public boolean CommitTransaction()
    { return CommitTransaction_7(); }

  private native boolean RollbackTransaction_8();
  public boolean RollbackTransaction()
    { return RollbackTransaction_8(); }

  private native long GetDatabase_9();
  public vtkSQLDatabase GetDatabase() {
    long temp = GetDatabase_9();

    if (temp == 0) return null;
    return (vtkSQLDatabase)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean BindParameter_10(int id0,char id1);
  public boolean BindParameter(int id0,char id1)
    { return BindParameter_10(id0,id1); }

  private native boolean BindParameter_11(int id0,double id1);
  public boolean BindParameter(int id0,double id1)
    { return BindParameter_11(id0,id1); }

  private native boolean BindParameter_12(int id0,String id1);
  public boolean BindParameter(int id0,String id1)
    { return BindParameter_12(id0,id1); }

  private native boolean ClearParameterBindings_13();
  public boolean ClearParameterBindings()
    { return ClearParameterBindings_13(); }

  private native String EscapeString_14(String id0,boolean id1);
  public String EscapeString(String id0,boolean id1)
    { return EscapeString_14(id0,id1); }

  public vtkSQLQuery() { super(); }

  public vtkSQLQuery(long id) { super(id); }

}
